/* Copyright (C) 2005 Chris Vine

The library comprised in this file or of which this file is part is
distributed by Chris Vine under the GNU Lesser General Public
License as follows:

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public License
   as published by the Free Software Foundation; either version 2.1 of
   the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License, version 2.1, for more details.

   You should have received a copy of the GNU Lesser General Public
   License, version 2.1, along with this library (see the file LGPL.TXT
   which came with this source code package in the src/utils sub-directory);
   if not, write to the Free Software Foundation, Inc.,
   59 Temple Place - Suite 330, Boston, MA, 02111-1307, USA.

*/

#ifndef UTF8_UTILS_H
#define UTF8_UTILS_H

#include <string>
#include <glib/gerror.h>
#include <glib/gunicode.h>

#include "shared_handle.h"

namespace Utf8 {

struct ConversionError {
  std::string message;
  ConversionError(GError* error_p): message((const char*)error_p->message) {}
};

std::string filename_from_utf8(const std::string& input);

std::string filename_to_utf8(const std::string& input); 

std::string locale_from_utf8(const std::string& input);

std::string locale_to_utf8(const std::string& input); 

inline std::string to_lower(const std::string& text) {
  GcharScopedHandle g_str_h(g_utf8_strdown(text.data(), text.size()));
  return std::string(g_str_h.get());
}

inline bool validate(const std::string& text) {
  return g_utf8_validate(text.data(), text.size(), 0);
}

} // namespace Utf8_utils

#endif
